@@ -26,14 +26,13 @@ def post__login(
 
 def act__login(name: str = None, pw: str = None) -> dict:
     resp = post__login(name, pw, ATestRequest(True))
-    assert resp[AA.HttpStatus] == HttpStatus.Ok_200.value
-    resp[AA.Token] = resp[AA.Data][AA.Token]
+    if resp[AA.Data] is not None:
+        assert resp[AA.HttpStatus] == HttpStatus.Ok_200.value
+        resp[AA.Token] = resp[AA.Data][AA.Token]
+    else:
+        assert AA.___Error___ in resp
     return resp
 
-def act__login___error(name: str = None, pw: str = None) -> dict:
-    resp = post__login(name, pw, ATestRequest(True))
-    assert AA.___Error___ in resp
-    return resp
 
 def act__signup_login(name: str = None, pw: str = None) -> dict:
     signup = act__signup(name, pw)
