@@ -1,7 +1,7 @@
 
 from volworld_aws_api_common.api.AA import AA
 
-URL_ROOT = "https://cxglkelavj.execute-api.ap-northeast-1.amazonaws.com/prod/"
+URL_ROOT = "https://958e36p8n5.execute-api.ap-northeast-1.amazonaws.com/prod/"
 
 
 def build_api_root_url(*elms) -> str:
